@@ -1,20 +1,34 @@
 #' Flexibly-shaped Spatial Scan Test
 #'
-#' \code{flex.test} performs the flexibly-shaped scan test of Tango and Takahashi (2005).
+#' \code{flex.test} performs the flexibly-shaped scan test
+#' of Tango and Takahashi (2005).
 #'
-#' The test is performed using the spatial scan test based on the Poisson test statistic and a fixed number of cases.  The first cluster is the most likely to be a cluster.  If no significant clusters are found, then the most likely cluster is returned (along with a warning).
+#' The test is performed using the spatial scan test based
+#' on the Poisson test statistic and a fixed number of
+#' cases.  The first cluster is the most likely to be a
+#' cluster.  If no significant clusters are found, then the
+#' most likely cluster is returned (along with a warning).
 #'
 #' @inheritParams rflex.test
 #' @param lonlat Deprecated in favor of \code{longlat}.
 #' @param ... Not used.
 #'
-#' @return Returns a list of length two of class scan. The first element (clusters) is a list containing the significant, non-ovlappering clusters, and has the the following components:
+#' @return Returns a list of length two of class scan. The
+#'   first element (clusters) is a list containing the
+#'   significant, non-ovlappering clusters, and has the the
+#'   following components:
 #' @author Joshua French
 #' @export
-#' @seealso \code{\link{scan.stat}}, \code{\link{plot.scan}},
-#' \code{\link{scan.test}}, \code{\link{uls.test}},
-#' \code{\link{dmst.test}}, \code{\link{bn.test}}
-#' @references Tango, T., & Takahashi, K. (2005). A flexibly shaped spatial scan statistic for detecting clusters. International journal of health geographics, 4(1), 11.  Kulldorff, M. (1997) A spatial scan statistic. Communications in Statistics -- Theory and Methods 26, 1481-1496.
+#' @seealso \code{\link{print.smerc_cluster}},
+#' \code{\link{summary.smerc_cluster}},
+#' \code{\link{plot.smerc_cluster}},
+#' \code{\link{scan.stat}}, \code{\link{scan.test}}
+#' @references Tango, T., & Takahashi, K. (2005). A flexibly
+#'   shaped spatial scan statistic for detecting clusters.
+#'   International journal of health geographics, 4(1), 11.
+#'   Kulldorff, M. (1997) A spatial scan statistic.
+#'   Communications in Statistics -- Theory and Methods 26,
+#'   1481-1496.
 #' @examples
 #' data(nydf)
 #' data(nyw)
@@ -79,21 +93,20 @@ flex.test = function(coords, cases, pop, w, k = 10,
     pvalue = rep(1, length(tobs))
   }
 
-  # determine which potential clusters are significant
-  sigc = which(pvalue <= alpha, useNames = FALSE)
+  # significant, ordered, non-overlapping clusters and
+  # information
+  pruned = sig_noc(tobs = tobs, zones = zones,
+                   pvalue = pvalue, alpha = alpha,
+                   order_by = "tobs")
 
-  # if there are no significant clusters, return most likely cluster
-  if (length(sigc) == 0) {
-    sigc = which.max(tobs)
-    warning("No significant clusters.  Returning most likely cluster.")
-  }
-
-  # only keep significant clusters
-  zones = zones[sigc]
-  tobs = tobs[sigc]
-  pvalue = pvalue[sigc]
-
-  prep.scan(tobs = tobs, zones = zones, pvalue = pvalue,
-            coords = coords, cases = cases, pop = pop,
-            ex = ex, longlat = longlat, w = w, d = NULL)
+  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
+                pvalue = pruned$pvalue, coords = coords,
+                cases = cases, pop = pop, ex = ex,
+                longlat = longlat, method = "flexible",
+                rel_param = list(type = type,
+                                 simdist = "multinomial",
+                                 nsim = nsim,
+                                 k = k),
+                alpha = alpha,
+                w = w, d = NULL)
 }
