@@ -43,10 +43,10 @@
 #'   of the list is the centroid coordinates.  This is
 #'   needed for plotting purposes.
 #' @author Joshua French
-#' @seealso \code{\link{scan.stat}},
-#'   \code{\link{plot.scan}}, \code{\link{scan.test}},
-#'   \code{\link{flex.test}}, \code{\link{dmst.test}},
-#'   \code{\link{bn.test}}
+#' @seealso \code{\link{print.smerc_cluster}},
+#' \code{\link{summary.smerc_cluster}},
+#' \code{\link{plot.smerc_cluster}},
+#' \code{\link{scan.stat}}, \code{\link{scan.test}}
 #' @export
 #' @references Patil, G.P. & Taillie, C. Upper level set
 #'   scan statistic for detecting arbitrarily shaped
@@ -102,22 +102,20 @@ uls.test = function(coords, cases, pop, w,
     pvalue = rep(1, length(tobs))
   }
 
-  # determine which potential clusters are significant
-  sigc = which(pvalue <= alpha, useNames = FALSE)
+  # significant, ordered, non-overlapping clusters and
+  # information
+  pruned = sig_noc(tobs = tobs, zones = zones,
+                   pvalue = pvalue, alpha = alpha,
+                   order_by = "tobs")
 
-  # if there are no significant clusters, return most likely cluster
-  if (length(sigc) == 0) {
-    sigc = which.max(tobs)
-    warning("No significant clusters.  Returning most likely cluster.")
-  }
-
-  # only keep significant clusters
-  zones = zones[sigc]
-  tobs = tobs[sigc]
-  pvalue = pvalue[sigc]
-
-  prep.scan(tobs = tobs, zones = zones, pvalue = pvalue,
-            coords = coords, cases = cases, pop = pop,
-            ex = ex, longlat = longlat, w = w,
-            d = NULL)
+  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
+                pvalue = pruned$pvalue, coords = coords,
+                cases = cases, pop = pop, ex = ex,
+                longlat = longlat, method = "upper level set",
+                rel_param = list(type = type,
+                                 simdist = "multinomial",
+                                 nsim = nsim,
+                                 ubpop = ubpop),
+                alpha = alpha,
+                w = w, d = NULL)
 }
